#!/usr/bin/env python

"""
DAC (signal generator) example layout
v3

Please adjust config.ini file. EasyTerm can be connected through USB or through USB-UART adapter
See manual (chapter "Master connection configurations") in case of problems
"""

import serial
import easyterm_api
import configparser
config = configparser.ConfigParser(inline_comment_prefixes="#")
config.read('config.ini')

with serial.Serial(config['COM']['CFG_COM_PORT'], int(config['COM']['CFG_BAUD_RATE']), timeout=float(config['COM']['CFG_REPLY_TIMEOUT'])) as ser:    
    et = easyterm_api.EasyTermApi(ser)
    
    #Uncomment to reset
    #et.soft_reset()
    
    #Clear current screen page to make sure there is space for widgets
    et.clear_screen_page()
    
    #Header
    et.transceive('dg x=60 y=5 w=200 h=3 c=0,0,100 ga=h gd=s gi=5;', echo=True)
    et.transceive('dt a=c x=160 y=10 t="DAC" f=18b;', echo=True)
    et.transceive('dg x=60 y=30 w=200 h=3 c=0,0,100 ga=h gd=s gi=5;', echo=True)
    
    #Constant voltage
    et.transceive('dt x=160 y=50 bw=310 t="Constant voltage" a=c ld=l;', echo=True)
    et.transceive('db x=80 y=66 c=0,0,100 w=160 h=40 t="Set voltage (mV)" a="DAC v=%d+DAC v=?";', echo=True)
    et.transceive('df x=115 y=107 w=90 gc=0,0,0 ft=ht t="Set value:" pm="DAC v=%d\\r\\n";', echo=True)
    
    #Waveform
    et.transceive('dt x=160 y=140 bw=310 t="Waveform (sine=default)" a=c ld=l;', echo=True)
    et.transceive('dc x=4 y=156 w=50 h=40 ta="DAC w=sine+ec id=1 s=0+ec id=2 s=0+ec id=3 s=0+ec id=4 s=0" ua="DAC w=sine+ec id=0 s=1" t="Sine" is=100 ot=1 bc=40,40,40 utc=60,60,60 to=c s=1 id=0;', echo=True)
    et.transceive('dc x=55 y=156 w=50 h=40 ta="DAC w=sawtooth+ec id=0 s=0+ec id=2 s=0+ec id=3 s=0+ec id=4 s=0" ua="DAC w=sine+ec id=0 s=1" t="Saw" is=100 ot=1 bc=40,40,40 utc=60,60,60 to=c id=1;', echo=True)
    et.transceive('dc x=106 y=156 w=50 h=40 ta="DAC w=triangle+ec id=0 s=0+ec id=1 s=0+ec id=3 s=0+ec id=4 s=0" ua="DAC w=sine+ec id=0 s=1" t="Trg" is=100 ot=1 bc=40,40,40 utc=60,60,60 to=c id=2;', echo=True)
    et.transceive('dc x=157 y=156 w=50 h=40 ta="DAC w=square+ec id=0 s=0+ec id=1 s=0+ec id=2 s=0+ec id=4 s=0" ua="DAC w=sine+ec id=0 s=1" t="Square" is=100 ot=1 bc=40,40,40 utc=60,60,60 to=c id=3;', echo=True)
    et.transceive('dc x=210 y=156 w=100 h=40 ta="DAC w=awg+ec id=0 s=0+ec id=1 s=0+ec id=2 s=0+ec id=3 s=0" ua="DAC w=sine+ec id=0 s=1" t="AWG" is=100 ot=1 bc=40,40,40 utc=60,60,60 to=c id=4;', echo=True)
    
    #Sine/saw/trg params
    et.transceive('dt x=80 y=226 bw=150 t="Sine/saw/trg params" a=c ld=l;', echo=True)
    et.transceive('db x=4 y=242 c=0,0,100 w=145 h=40 t="Frequency (Hz)" a="DAC wf=%d";', echo=True)
    et.transceive('db x=4 y=283 c=0,0,100 w=72 h=40 t="Pk-pk (mV)" a="DAC wa=%d";', echo=True)
    et.transceive('db x=77 y=283 c=0,0,100 w=72 h=40 t="Offset (mV)" a="DAC wo=%d";', echo=True)
    
    #Square params
    et.transceive('dt x=80 y=330 bw=150 t="Square params" a=c ld=l;', echo=True)
    et.transceive('db x=4 y=346 c=0,0,100 w=145 h=40 t="Duty cycle" a="DAC sdc=%d";', echo=True)
    
    
    #AWG samples
    et.transceive('dt x=240 y=226 bw=150 t="AWG samples" a=c ld=l;', echo=True)
    et.transceive('db x=165 y=242 c=0,0,100 w=72 h=40 t="Sample index" a="DAC si=%d";', echo=True)
    et.transceive('db x=238 y=242 c=0,0,100 w=72 h=40 t="Sample (mV)" a="DAC s=%d";', echo=True)
    
    #AWG generator
    et.transceive('dt x=240 y=289 bw=150 t="AWG generator" a=c ld=l;', echo=True)
    et.transceive('db x=165 y=305 c=0,0,100 w=72 h=40 t="Start index" a="DAC ssi=%d";', echo=True)
    et.transceive('db x=238 y=305 c=0,0,100 w=72 h=40 t="Stop index" a="DAC esi=%d";', echo=True)
    et.transceive('db x=165 y=346 c=0,0,100 w=72 h=40 t="Rate (us)" a="DAC sr=%dus";', echo=True)
    et.transceive('db x=238 y=346 c=0,0,100 w=72 h=40 t="Rate (Hz)" a="DAC sr=%dHz";', echo=True)

    #Conversion
    et.transceive('dt x=160 y=404 bw=310 t="Conversion" a=c ld=l;', echo=True)
    et.transceive('db x=4 y=420 c=0,0,100 w=109 h=40 t="Start continuous" a="DAC os=0 cc=1";', echo=True)
    et.transceive('db x=114 y=420 c=0,0,100 w=109 h=40 t="Start one-shot" a="DAC cc=0 os=1";', echo=True)
    et.transceive('db x=224 y=420 c=0,0,100 w=90 h=40 t="Stop" a="DAC os=0 cc=0";', echo=True)
    
    #EasyTerm replies form
    et.transceive('dg x=10 y=463 w=300 h=1 c=50,50,50;', echo=True)
    et.transceive('df x=0 y=465 w=320 h=15 ft=vo pm="%s\\r\\n";', echo=True)
    
    #Uncomment to save layout in flash and recover after device startup
    #et.transceive('sl bid=0;', echo=True, custom_timeout=2)
    #et.transceive('sys coi="ll bid=0";', echo=True, custom_timeout=2)
    
