#!/usr/bin/env python

"""
I2C example layout
v3

Please adjust config.ini file. EasyTerm can be connected through USB or through USB-UART adapter
See manual (chapter "Master connection configurations") in case of problems
"""

import serial
import easyterm_api
import configparser
config = configparser.ConfigParser(inline_comment_prefixes="#")
config.read('config.ini')

with serial.Serial(config['COM']['CFG_COM_PORT'], int(config['COM']['CFG_BAUD_RATE']), timeout=float(config['COM']['CFG_REPLY_TIMEOUT'])) as ser:    
    et = easyterm_api.EasyTermApi(ser)
    
    #Uncomment to reset
    #et.soft_reset()
    
    #Clear current screen page to make sure there is space for widgets
    et.clear_screen_page()
    
    #Header
    et.transceive('dg x=60 y=5 w=200 h=3 c=0,0,100 ga=h gd=s gi=5;', echo=True)
    et.transceive('dt a=c x=160 y=10 t="I2C" f=18b;', echo=True)
    et.transceive('dg x=60 y=30 w=200 h=3 c=0,0,100 ga=h gd=s gi=5;', echo=True)
    
    #Init
    et.transceive('db x=125 y=38 c=0,0,100 w=70 h=30 t="Init" a="I2C i=1" id=0;', echo=True)
    
    #Frequency
    et.transceive('dt x=35 y=70 bw=65 t="Frequency" a=c ld=l;', echo=True)
    et.transceive('db x=4 y=86 c=0,0,100 w=65 h=40 t="100kHz|10kHz|400kHz|1MHz" a="I2C f=100kHz|I2C f=10kHz|I2C f=400kHz|I2C f=1MHz" id=1;', echo=True)
    
    #10b addressing
    et.transceive('dt x=125 y=70 bw=100 t="10b addressing" a=c ld=l;', echo=True)
    et.transceive('dc x=75 y=86 w=50 h=40 ta="I2C 10ba=0+ec id=1 s=0" ua="ec id=0 s=1" t="Disabled" s=1 is=100 ot=1 bc=40,40,40 utc=60,60,60 to=c id=0;', echo=True)
    et.transceive('dc x=125 y=86 w=50 h=40 ta="I2C 10ba=1+ec id=0 s=0" ua="ec id=1 s=1" t="Enabled" is=100 ot=1 bc=40,40,40 utc=60,60,60 to=c id=1;', echo=True)
    
    #Address
    et.transceive('dt x=205 y=70 bw=55 t="Address" a=c ld=l;', echo=True)
    et.transceive('db x=180 y=86 c=0,0,100 w=50 h=40 t="00" a="I2C a=%x+eb id=2 t=\\"%_\\"" id=2;', echo=True)
    
    #Read format
    et.transceive('dt x=275 y=70 bw=78 t="Read format" a=c ld=l;', echo=True)
    et.transceive('db x=235 y=86 c=0,0,100 w=80 h=40 t="0x1" a="I2C rf=\\"%s\\"+eb id=3 t=\\"%_\\"" id=3;', echo=True)

    #Write
    et.transceive('dt x=160 y=140 bw=200 t="Transactions" a=c ld=l;', echo=True)
    et.transceive('db x=60 y=156 c=0,0,100 w=50 h=40 t="Write" a="I2C wr=%x" id=4;', echo=True)

    #Read
    et.transceive('db x=111 y=156 c=0,0,100 w=50 h=40 t="Read" a="I2C rd=%d" id=5;', echo=True)
    
    #Write and read
    et.transceive('db x=162 y=156 c=0,0,100 w=100 h=40 t="Write and read" a="I2C wrrd=%x,%d" id=6;', echo=True)
    
    #RD command replies form
    et.transceive('df x=0 y=210 w=320 h=30 t="- Read data -" pm="rd=%s\\r\\n";', echo=True)
    
    #EasyTerm replies form
    et.transceive('dg x=10 y=463 w=300 h=1 c=50,50,50;', echo=True)
    et.transceive('df x=0 y=465 w=320 h=15 ft=vo pm="%s\\r\\n";', echo=True)

    #Uncomment to save layout in flash and recover after device startup
    #et.transceive('sl bid=0;', echo=True, custom_timeout=2)
    #et.transceive('sys coi="ll bid=0";', echo=True, custom_timeout=2)
    
