#!/usr/bin/env python

"""
SPI example layout
v4

Please adjust config.ini file. EasyTerm can be connected through USB or through USB-UART adapter
See manual (chapter "Master connection configurations") in case of problems
"""

import serial
import easyterm_api
import configparser
config = configparser.ConfigParser(inline_comment_prefixes="#")
config.read('config.ini')

with serial.Serial(config['COM']['CFG_COM_PORT'], int(config['COM']['CFG_BAUD_RATE']), timeout=float(config['COM']['CFG_REPLY_TIMEOUT'])) as ser:    
    et = easyterm_api.EasyTermApi(ser)
    
    #Uncomment to reset
    #et.soft_reset()
    
    #Clear current screen page to make sure there is space for widgets
    et.clear_screen_page()
    
    #Header
    et.transceive('dg x=60 y=5 w=200 h=3 c=0,0,100 ga=h gd=s gi=5;', echo=True)
    et.transceive('dt a=c x=160 y=10 t="SPI" f=18b;', echo=True)
    et.transceive('dg x=60 y=30 w=200 h=3 c=0,0,100 ga=h gd=s gi=5;', echo=True)
    
    #Init
    et.transceive('db x=125 y=38 c=0,0,100 w=70 h=30 t="Init" a="SPI i=1" id=0;', echo=True)
    
    #Frequency
    et.transceive('dt x=40 y=70 bw=70 t="Frequency" a=c ld=l;', echo=True)
    et.transceive('db x=4 y=86 c=0,0,100 w=70 h=40 t="1.25MHz|312.5kHz|625kHz|2.5MHz|5MHz|10MHz|20MHz|40MHz" a="SPI f=1250kHz|SPI f=312500Hz|SPI f=625kHz|SPI f=2500kHz|SPI f=5MHz|SPI f=10MHz|SPI f=20MHz|SPI f=40MHz" id=1;', echo=True)
    
    #Clock polarity
    et.transceive('dt x=140 y=70 bw=108 t="Clock polarity" a=c ld=l;', echo=True)
    et.transceive('dc x=85 y=86 w=55 h=40 ta="SPI cpol=0+ec id=1 s=0" ua="ec id=0 s=1" t="Normal" s=1 is=100 ot=1 bc=40,40,40 utc=60,60,60 to=c id=0;', echo=True)
    et.transceive('dc x=140 y=86 w=55 h=40 ta="SPI cpol=1+ec id=0 s=0" ua="ec id=1 s=1" t="Inverted" is=100 ot=1 bc=40,40,40 utc=60,60,60 to=c id=1;', echo=True)
    
    #Clock phase
    et.transceive('dt x=260 y=70 bw=108 t="Clock phase" a=c ld=l;', echo=True)
    et.transceive('dc x=205 y=86 w=55 h=40 ta="SPI cpha=0+ec id=3 s=0" ua="ec id=2 s=1" t="Normal" s=1 is=100 ot=1 bc=40,40,40 utc=60,60,60 to=c id=2;', echo=True)
    et.transceive('dc x=260 y=86 w=55 h=40 ta="SPI cpha=1+ec id=2 s=0" ua="ec id=3 s=1" t="Inverted" is=100 ot=1 bc=40,40,40 utc=60,60,60 to=c id=3;', echo=True)
    
    
    #CS Pin
    et.transceive('dt x=40 y=130 bw=70 t="CS pin" a=c ld=l;', echo=True)
    et.transceive('db x=4 y=146 c=0,0,100 w=70 h=40 t="None" a="SPI csio=%d+eb id=2 t=\\"%_\\"" id=2;', echo=True)

    #Automatic chip-select
    et.transceive('dt x=140 y=130 bw=108 t="Automatic CS" a=c ld=l;', echo=True)
    et.transceive('dc x=85 y=146 w=55 h=40 ta="SPI acs=0+ec id=5 s=0" ua="ec id=4 s=1" t="Disabled" s=1 is=100 ot=1 bc=40,40,40 utc=60,60,60 to=c id=4;', echo=True)
    et.transceive('dc x=140 y=146 w=55 h=40 ta="SPI acs=1+ec id=4 s=0" ua="ec id=5 s=1" t="Enabled" is=100 ot=1 bc=40,40,40 utc=60,60,60 to=c id=5;', echo=True)

    #Dummy word
    et.transceive('dt x=260 y=130 bw=108 t="Dummy word" a=c ld=l;', echo=True)
    et.transceive('db x=205 y=146 c=0,0,100 w=110 h=40 t="FF" a="SPI dw=%x+eb id=3 t=\\"%_\\"" id=3;', echo=True)
    
    
    #Word length
    et.transceive('dt x=40 y=190 bw=70 t="Word length" a=c ld=l;', echo=True)
    et.transceive('db x=4 y=206 c=0,0,100 w=70 h=40 t="8" a="SPI wl=%d+eb id=4 t=\\"%_\\"" id=4;', echo=True)
    
    #LSb first
    et.transceive('dt x=140 y=190 bw=108 t="LSb first" a=c ld=l;', echo=True)
    et.transceive('dc x=85 y=206 w=55 h=40 ta="SPI lsbf=0+ec id=7 s=0" ua="ec id=6 s=1" t="Disabled" s=1 is=100 ot=1 bc=40,40,40 utc=60,60,60 to=c id=6;', echo=True)
    et.transceive('dc x=140 y=206 w=55 h=40 ta="SPI lsbf=1+ec id=6 s=0" ua="ec id=7 s=1" t="Enabled" is=100 ot=1 bc=40,40,40 utc=60,60,60 to=c id=7;', echo=True)
    
    #Read format
    et.transceive('dt x=260 y=190 bw=108 t="Read format" a=c ld=l;', echo=True)
    et.transceive('db x=205 y=206 c=0,0,100 w=110 h=40 t="0x1" a="SPI rf=\\"%s\\"+eb id=6 t=\\"%_\\"" id=6;', echo=True)
    
    
    #Half-duplex
    et.transceive('dt x=140 y=250 bw=108 t="Half-duplex\\ntransmission" a=c ld=l;', echo=True)
    et.transceive('dc x=85 y=280 w=55 h=30 ta="SPI hd=0+ec id=9 s=0" ua="ec id=8 s=1" t="Disabled" s=1 is=100 ot=1 bc=40,40,40 utc=60,60,60 to=c id=8;', echo=True)
    et.transceive('dc x=140 y=280 w=55 h=30 ta="SPI hd=1+ec id=8 s=0" ua="ec id=9 s=1" t="Enabled" is=100 ot=1 bc=40,40,40 utc=60,60,60 to=c id=9;', echo=True)
    
    #Bytes before read valid
    et.transceive('dt x=260 y=250 bw=108 t="Words before\\nread valid" a=c ld=l;', echo=True)
    et.transceive('db x=205 y=280 c=0,0,100 w=110 h=30 t="0" a="SPI wbrv=%d+eb id=5 t=\\"%_\\"" id=5;', echo=True)
    
    #Transmit and receive
    et.transceive('dt x=160 y=315 bw=304 t="Transmit/receive" a=c ld=l;', echo=True)
    et.transceive('db x=4 y=331 c=0,0,100 w=60 h=40 t="Transmit" a="SPI tx=%x";', echo=True)
    et.transceive('db x=65 y=331 c=0,0,100 w=60 h=40 t="Receive" a="SPI rx=%d";', echo=True)
    et.transceive('db x=126 y=331 c=0,0,100 w=190 h=40 t="Transmit and receive" a="SPI txrx=%x,%d";', echo=True)
    
    #RX command replies form
    et.transceive('df x=20 y=385 w=280 h=30 t="- RX data -" pm="rx=%s\\r\\n";', echo=True)
    
    #EasyTerm replies form
    et.transceive('dg x=10 y=463 w=300 h=1 c=50,50,50;', echo=True)
    et.transceive('df x=0 y=465 w=320 h=15 ft=vo pm="%s\\r\\n";', echo=True)

    #Uncomment to save layout in flash and recover after device startup
    #et.transceive('sl bid=0;', echo=True, custom_timeout=2)
    #et.transceive('sys coi="ll bid=0";', echo=True, custom_timeout=2)
    
