#!/usr/bin/env python

"""
WIFI example layout
v1

Replace "myap" and "pass1234" with your WIFI AP SSID and password
Replace MQTT broker configuration (cmb command) and topics (rct, ms and mp commands) as you see fit (free non-private testing configuration is used)
Please adjust config.ini file. EasyTerm can be connected through USB or through USB-UART adapter
See manual (chapter "Master connection configurations") in case of problems
"""

import serial
import easyterm_api
import configparser
config = configparser.ConfigParser(inline_comment_prefixes="#")
config.read('config.ini')

with serial.Serial(config['COM']['CFG_COM_PORT'], int(config['COM']['CFG_BAUD_RATE']), timeout=float(config['COM']['CFG_REPLY_TIMEOUT'])) as ser:    
    et = easyterm_api.EasyTermApi(ser)
    
    #Uncomment to reset
    #et.soft_reset()
    
    #Clear current screen page to make sure there is space for widgets
    et.clear_screen_page()
    
    #Header
    et.transceive('dg x=60 y=5 w=200 h=3 c=0,0,100 ga=h gd=s gi=5;', echo=True)
    et.transceive('dt a=c x=160 y=10 t="WIFI" f=18b;', echo=True)
    et.transceive('dg x=60 y=30 w=200 h=3 c=0,0,100 ga=h gd=s gi=5;', echo=True)
    
    #Init
    et.transceive('db x=125 y=38 c=0,0,100 w=70 h=30 t="Init" a="WIFI i=1";', echo=True)
    
    #Power management
    et.transceive('dt x=156 y=70 bw=312 t="Wi-Fi power management" a=c ld=l;', echo=True)
    et.transceive('db x=4 y=86 w=70 h=40 t="Set wakeIO" a="WIFI wakeIO=%d";', echo=True)
    et.transceive('db x=75 y=86 w=55 h=40 t="Sleep" a="WIFI sleep";', echo=True)
    et.transceive('db x=131 y=86 w=55 h=40 t="Wake" a="WIFI wake";', echo=True)
    et.transceive('db x=187 y=86 w=64 h=40 a="sys vs=0" t="VOUT OFF";', echo=True)
    et.transceive('db x=252 y=86 w=64 h=40 a="sys vs=1" t="VOUT ON";', echo=True)

    #AP
    et.transceive('dt x=84 y=130 bw=141 t="Access points" a=c ld=l;', echo=True)
    et.transceive('db x=14 y=146 w=70 h=40 a="WIFI cap=\\"myap\\",\\"pass1234\\"" t="Connect AP";', echo=True)
    et.transceive('db x=85 y=146 c=0,0,100 w=70 h=40 t="Scan APs" a="WIFI scan";', echo=True)
    
    et.transceive('dt x=235 y=130 bw=141 t="Extras" a=c ld=l;', echo=True)
    et.transceive('db x=165 y=146 w=70 h=40 a="Wifi version=?" t="Version";', echo=True)
    et.transceive('db x=236 y=146 w=70 h=40 a="AT\+%s\\r\\n" t="AT CMD";', echo=True)
    
    #Connection and HTTP
    et.transceive('dt x=84 y=190 bw=141 t="HTTP examples" a=c ld=l;', echo=True)
    et.transceive('db x=14 y=206 w=70 h=40 a="WIFI httpGet=\\"https://timeapi.io/api/Time/current/zone?timeZone=Europe/Prague\\"" t="GET time";', echo=True)
    et.transceive('db x=85 y=206 w=70 h=40 a="WIFI httpPostJson=\\"https://api.restful-api.dev/objects\\",\\"{\\\\"name\\\\":\\\\"POKUS\\\\"}\\"" t="POST JSON";', echo=True)

    #Alternate UART
    et.transceive('dt x=235 y=190 bw=141 t="Alternate UART" a=c ld=l;', echo=True)
    et.transceive('db x=165 y=206 w=70 h=40 a="sys uahu=0" t="Disable";', echo=True)
    et.transceive('db x=236 y=206 w=70 h=40 a="sys uahu=1" t="Enable";', echo=True)
    
    #MQTT
    et.transceive('dt x=160 y=250 bw=312 t="MQTT" a=c ld=l;', echo=True)
    et.transceive('db x=4 y=266 w=77 h=40 a="WIFI cmb=\\"test.mosquitto.org\\",1883,\\"ESP8662\\"" t="Connect\\nbroker";', echo=True)
    et.transceive('db x=82 y=266 w=77 h=40 a="WIFI rct=\\"ET_CMD_TOPIC\\",\\"ET_REPLY_TOPIC\\"" t="Subscribe\\nCMD topics";', echo=True)
    et.transceive('db x=160 y=266 w=77 h=40 a="WIFI ms=\\"ET_MSG_TOPIC\\",0" t="Subscribe\\ngeneral topic";', echo=True)
    et.transceive('db x=238 y=266 w=77 h=40 a="WIFI mp=\\"ET_MSG_TOPIC\\",0,0,\\"%s\\"" t="Publish\\nmessage";', echo=True)
    et.transceive('df x=0 y=320 w=160 t="Parsed HTTP time" pm="\\"time\\":\\"%s\\"";', echo=True)
    et.transceive('df x=160 y=320 w=160 t="Parsed MQTT MSG" pm="WIFI mm=%s\\r\\n";', echo=True)

    #LogWin
    et.transceive('dl y=380 h=100;', echo=True)

    #Uncomment to save layout in flash and recover after device startup
    et.transceive('sl bid=0;', echo=True, custom_timeout=2)
    et.transceive('sys coi="ll bid=0";', echo=True, custom_timeout=2)
